@@ -11,7 +11,7 @@ use File::Spec;
 use File::Basename ();
 use URI::Escape ();
 
-our $VERSION = '0.990105';
+our $VERSION = '0.990106';
 
 use constant CHUNK_SIZE => 4096;
 
@@ -889,11 +889,11 @@ sub _parse_text {
         my $t;
         my $escape = 0;
         my $found  = 0;
-        if ($text =~ s/^(.*?)?(?<!\\)\#{//) {
+        if ($text =~ s/^(.*?)?(?<!\\)\#\{//) {
             $found = 1;
             $t     = $1;
         }
-        elsif ($text =~ s/^(.*?)?\\\\\#{//) {
+        elsif ($text =~ s/^(.*?)?\\\\\#\{//) {
             $found  = 1;
             $t      = $1;
             $escape = 1;
@@ -905,7 +905,7 @@ sub _parse_text {
         }
 
         if ($found) {
-            $text =~ s/^([^}]+)}//;
+            $text =~ s/^([^}]+)\}//;
 
             my $prefix = $escape ? quotemeta("\\") : '';
             $output .= qq/$prefix".$1."/;
